@@ -104,7 +104,10 @@ def predict(
 
     merged = None
     if merge_method == "mean":
-        merged = np.average(arr, axis=2, weights=weights_norm)
+        merged = np.average(arr, axis=2, weights=weights_norm, keepdims=True)
+
+        if confidence_output:
+            weights = np.average(weights, axis=2, weights=weights_norm, keepdims=True)
 
     elif merge_method == "max_conf":
         mask = np.argmax(weights, axis=-1)[:, :, np.newaxis] == np.tile(
@@ -112,14 +115,22 @@ def predict(
         ).reshape(weights.shape[0], weights.shape[1], weights.shape[2])
 
         merged = np.ma.masked_array(arr, mask=~mask).max(axis=2).filled(0)[:, :, np.newaxis]
-        weights = np.ma.masked_array(weights, mask=~mask).max(axis=2).filled(0)[:, :, np.newaxis]
+
+        if confidence_output:
+            weights = np.ma.masked_array(weights, mask=~mask).max(axis=2).filled(0)[:, :, np.newaxis]
 
     elif merge_method == "median":
         merged = beo.weighted_median(arr, weights_norm)
 
+        if confidence_output:
+            weights = beo.weighted_median(weights, weights_norm)
+
     elif merge_method == "mad":
         merged = beo.mad_merge(arr, weights_norm)
 
+        if confidence_output:
+            weights = beo.mad_merge(weights, weights_norm)
+
     if confidence_output:
         return merged, weights
     
